@@ -22,7 +22,7 @@ class ABC::Note does ABC::Duration does ABC::Pitched {
     }
 
     method perl() {
-        "ABC::Note.new({ $.accidental.perl }, { $.basenote.perl }, { $.octave.perl } { $.ticks.perl }, { $.is-tie.perl })";
+        "ABC::Note.new({ $.accidental.perl }, { $.basenote.perl }, { $.octave.perl }, { $.ticks.perl }, { $.is-tie.perl })";
     }
 
     method transpose($pitch-changer) {
